@@ -1,5 +1,7 @@
 package Plack::Middleware::Timeout;
 
+use strict;
+use warnings;
 use parent 'Plack::Middleware';
 use Plack::Util::Accessor qw(timeout response soft_timeout on_soft_timeout);
 use Plack::Request;
@@ -8,7 +10,7 @@ use Scope::Guard ();
 use Time::HiRes qw(alarm time);
 use Carp qw(croak);
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub prepare_app {
     my $self = shift;
@@ -57,7 +59,6 @@ sub call {
                         $on_soft_timeout->(
                             $request->uri,
                             $soft_timeout,
-                            $execution_time,
                         );
                     }
                 }
@@ -71,7 +72,7 @@ sub call {
 
         my $response = Plack::Response->new(408);
         if ( my $build_response_coderef = $self->response ) {
-            $build_response_coderef->($response,$execution_time);
+            $build_response_coderef->($response);
         }
         else {
             # warn by default, so there's a trace of the timeout left somewhere
@@ -102,7 +103,7 @@ Plack::Middleware::Timeout
         timeout  => sub { ... } || 120,
         # optional callback to set the custom response 
         response => sub {
-            my ($response_obj,$execution_time) = @_;
+            my ($response_obj) = @_;
 
             $response_obj->code(HTTP_REQUEST_TIMEOUT);
             $response_obj->body( encode_json({
@@ -128,7 +129,7 @@ Numeric value accepted by subroutine defined in Time::HiRes::alarm, default 120
 
 =item response
 
-Optional subroutine which will be exeuted when timeout is reached. The subref receives a Plack::Response object and time it took to run as its arguments. If the response subref isn't defined, we resolve to emitting a warning: 
+Optional subroutine which will be exeuted when timeout is reached. The subref receives a Plack::Response object as argument. If the response subref isn't defined, we resolve to emitting a warning: 
 
 =over
 
